@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
 our $DATE = '2019-04-23'; # DATE
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict;
@@ -35,6 +35,21 @@ sub _get_csv_row {
     $csv->string . "\n";
 }
 
+sub _instantiate_parser {
+    require Text::CSV_XS;
+
+    my $args = shift;
+
+    my %tcsv_opts = (binary=>1);
+    if ($args->{tsv}) {
+        $tcsv_opts{sep_char}    = "\t";
+        $tcsv_opts{quote_char}  = undef;
+        $tcsv_opts{escape_char} = undef;
+    }
+
+    Text::CSV_XS->new(\%tcsv_opts);
+}
+
 sub _complete_field_or_field_list {
     # return list of known fields of a CSV
 
@@ -65,8 +80,7 @@ sub _complete_field_or_field_list {
     return undef unless defined $args && $args->{filename};
 
     # can the file be opened?
-    require Text::CSV_XS;
-    my $csv = Text::CSV_XS->new({binary => 1});
+    my $csv = _instantiate_parser(\%args);
     open my($fh), "<:encoding(utf8)", $args->{filename} or
         return [];
 
@@ -109,6 +123,10 @@ will be named `field1`, `field2`, and so on.
 
 _
     },
+    tsv => {
+        summary => "Inform that input file is in TSV (tab-separated) format instead of CSV",
+        schema => 'bool*',
+    },
 );
 
 my %arg_filename_1 = (
@@ -301,14 +319,12 @@ $SPEC{csvutil} = {
     },
 };
 sub csvutil {
-    require Text::CSV_XS;
-
     my %args = @_;
     my $action = $args{action};
     my $has_header = $args{header} // 1;
     my $add_newline = $args{add_newline} // 1;
 
-    my $csv = Text::CSV_XS->new({binary => 1});
+    my $csv = _instantiate_parser(\%args);
     open my($fh), "<:encoding(utf8)", $args{filename} or
         return [500, "Can't open input filename '$args{filename}': $!"];
 
@@ -769,12 +785,10 @@ _
     },
 };
 sub csv_replace_newline {
-    require Text::CSV_XS;
-
     my %args = @_;
     my $with = $args{with};
 
-    my $csv = Text::CSV_XS->new({binary => 1});
+    my $csv = _instantiate_parser(\%args);
     open my($fh), "<:encoding(utf8)", $args{filename} or
         return [500, "Can't open input filename '$args{filename}': $!"];
 
@@ -1052,15 +1066,13 @@ _
     },
 };
 sub csv_concat {
-    require Text::CSV_XS;
-
     my %args = @_;
 
     my %res_field_idxs;
     my @rows;
 
     for my $filename (@{ $args{filenames} }) {
-        my $csv = Text::CSV_XS->new({binary => 1});
+        my $csv = _instantiate_parser(\%args);
         open my($fh), "<:encoding(utf8)", $filename or
             return [500, "Can't open input filename '$filename': $!"];
         my $i = 0;
@@ -1087,7 +1099,7 @@ sub csv_concat {
 
     my $num_fields = keys %res_field_idxs;
     my $res = "";
-    my $csv = Text::CSV_XS->new({binary => 1});
+    my $csv = _instantiate_parser(\%args);
 
     # generate header
     my $status = $csv->combine(
@@ -1153,7 +1165,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.017 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-23.
+This document describes version 0.018 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-23.
 
 =head1 DESCRIPTION
 
@@ -1255,6 +1267,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1295,6 +1311,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =item * B<with_data_rows> => I<bool>
 
 Whether to also output data rows.
@@ -1369,6 +1389,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1413,6 +1437,10 @@ will be named C<field1>, C<field2>, and so on.
 
 Row number (e.g. 2 for first data row).
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1457,6 +1485,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1501,6 +1533,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1565,6 +1601,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1640,6 +1680,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1680,6 +1724,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1755,6 +1803,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1809,6 +1861,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1855,6 +1911,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =item * B<with> => I<str> (default: " ")
 
 =back
@@ -1905,6 +1965,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1949,6 +2013,10 @@ will be named C<field1>, C<field2>, and so on.
 
 Row number (e.g. 2 for first data row), range (2-7), or comma-separated list of such (2-7,10,20-23).
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -1997,6 +2065,10 @@ will be named C<field1>, C<field2>, and so on.
 
 =item * B<reverse> => I<bool>
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =back
 
 Returns an enveloped result (an array).
@@ -2037,6 +2109,10 @@ Whether CSV has a header row.
 When you declare that CSV does not have header row (C<--no-header>), the fields
 will be named C<field1>, C<field2>, and so on.
 
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
 =item * B<with_data_rows> => I<bool>
 
 Whether to also output data rows.
